tinymce.addI18n('kab',{
"Cut": "Gzem",
"Heading 5": "Heading 5",
"Header 2": "Azwel 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.",
"Heading 4": "Heading 4",
"Div": "Div",
"Heading 2": "Heading 2",
"Paste": "Sente\u1e0d",
"Close": "Mdel",
"Font Family": "Tasefsit",
"Pre": "Pre",
"Align right": "tarigla \u0263er zelma\u1e0d",
"New document": "Arrat amaynut",
"Blockquote": "Blockquote",
"Numbered list": "Tabdart s wu\u1e6d\u1e6dunen",
"Heading 1": "Heading 1",
"Headings": "Izewlen",
"Increase indent": "Sim\u0263ur asi\u1e93i",
"Formats": "Imasalen",
"Headers": "Headers",
"Select all": "Fren kulec",
"Header 3": "Azwel 3",
"Blocks": "I\u1e25edran",
"Undo": "Err-d",
"Strikethrough": "Strikethrough",
"Bullet list": "Tabdart s tlillac",
"Header 1": "Azwel 1",
"Superscript": "Superscript",
"Clear formatting": "Clear formatting",
"Font Sizes": "Tiddi n tsefsit",
"Subscript": "Subscript",
"Header 6": "Azwel 6",
"Redo": "Redo",
"Paragraph": "taseddart",
"Ok": "Ih",
"Bold": "Tira tazurant",
"Code": "Tangalt",
"Italic": "Tira yeknan",
"Align center": "Di tlemast",
"Header 5": "Azwel 5",
"Heading 6": "Heading 6",
"Heading 3": "Heading 3",
"Decrease indent": "Simc\u1e6du\u1e25 asi\u1e93i",
"Header 4": "Azwel 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.",
"Underline": "Aderrer",
"Cancel": "Semmet",
"Justify": "Justify",
"Inline": "Inline",
"Copy": "N\u0263el",
"Align left": "Tarigla \u0263er zelma\u1e0d",
"Visual aids": "Visual aids",
"Lower Greek": "Grik ame\u1e93yan",
"Square": "Amku\u1e93",
"Default": "Lex\u1e63as",
"Lower Alpha": "Alpha ame\u1e93yan",
"Circle": "Tawinest",
"Disc": "A\u1e0debsi",
"Upper Alpha": "Alfa ameqran",
"Upper Roman": "Ruman ameqran",
"Lower Roman": "Ruman amectu\u1e25",
"Name": "Isem",
"Anchor": "Tamdeyt",
"You have unsaved changes are you sure you want to navigate away?": "Ibeddilen ur twaskelsen ara teb\u0263i\u1e0d ad teff\u0263e\u1e0d ?",
"Restore last draft": "Restore last draft",
"Special character": "Askil uslig",
"Source code": "Tangalt ta\u0263balut",
"B": "B",
"R": "R",
"G": "G",
"Color": "Ini",
"Right to left": "Seg yefus \u0263er zelma\u1e0d",
"Left to right": "Seg zelma\u1e0d \u0263er yefus",
"Emoticons": "Emoticons",
"Robots": "Robots",
"Document properties": "Iraten n warat",
"Title": "Azwel",
"Keywords": "Awalen yufraren",
"Encoding": "Asettengel",
"Description": "Aglam",
"Author": "Ameskar",
"Fullscreen": "Agdil a\u010duran",
"Horizontal line": "Ajerri\u1e0d aglawan",
"Horizontal space": "Talunt taglawant",
"Insert\/edit image": "Ger\/\u1e92reg tugna",
"General": "Amatu",
"Advanced": "Ana\u1e93i",
"Source": "A\u0263balu",
"Border": "Iri",
"Constrain proportions": "Constrain proportions",
"Vertical space": "Talunt taratakt",
"Image description": "Aglam n tugna",
"Style": "A\u0263anib",
"Dimensions": "Tisekta",
"Insert image": "Ger tugna",
"Zoom in": "Zoom in",
"Contrast": "Contrast",
"Back": "Tu\u0263alin",
"Gamma": "Gamma",
"Flip horizontally": "Tuzttya tagrawant",
"Resize": "Beddel tiddi",
"Sharpen": "Affiner",
"Zoom out": "Zoom out",
"Image options": "Tixti\u1e5biyin n tugna",
"Apply": "Snes",
"Brightness": "Tafat",
"Rotate clockwise": "Tuzya yugdan tamrilt",
"Rotate counterclockwise": "Tuzya mgal tamrilt",
"Edit image": "\u1e92reg tugna",
"Color levels": "Iswiren n yini",
"Crop": "Rogner",
"Orientation": "Ta\u0263da",
"Flip vertically": "Tuzya taratakt",
"Invert": "Tti",
"Insert date\/time": "Ger azemz\/asrag",
"Remove link": "Kkes azday",
"Url": "Url",
"Text to display": "A\u1e0dris ara yettwabeqq\u1e0den",
"Anchors": "Timdyin",
"Insert link": "Ger azday",
"New window": "Asfaylu amaynut",
"None": "Ulac",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "URL i teskecme\u1e0d tettban-d d azday uffi\u0263. Teb\u0263i\u1e0d ad s-ternu\u1e0d azwir http:\/\/  ?",
"Target": "Target",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "URL i teskecme\u1e0d tettban-d d tansa email. teb\u0263i\u1e0d ad s-ternu\u1e0d azwir mailto : ?",
"Insert\/edit link": "Ger\/\u1e93reg azday",
"Insert\/edit video": "Ger\/\u1e93reg avidyu",
"Poster": "Poster",
"Alternative source": "A\u0263balu amlellay",
"Paste your embed code below:": "Paste your embed code below:",
"Insert video": "Ger avidyu",
"Embed": "Embed",
"Nonbreaking space": "Talunt ur nettwagzam ara",
"Page break": "Angaz n usebter",
"Paste as text": "Sente\u1e0d d a\u1e0dris",
"Preview": "Sken",
"Print": "Siggez",
"Save": "Sekles",
"Could not find the specified string.": "Ur d-nufi ara azrar i d-yettunefken.",
"Replace": "Semselsi",
"Next": "Win \u0263ers",
"Whole words": "Awal ummid",
"Find and replace": "Nadi semselsi",
"Replace with": "Semselsi s",
"Find": "Nadi",
"Replace all": "Semselsi kulec",
"Match case": "Match case",
"Prev": "Win yezrin",
"Spellcheck": "Ase\u0263ti n tira",
"Finish": "Fak",
"Ignore all": "Zgel kulec",
"Ignore": "Zgel",
"Add to Dictionary": "Rnu-t s amawal",
"Insert row before": "Ger adur deffir",
"Rows": "Aduren",
"Height": "Te\u0263zi",
"Paste row after": "Sente\u1e0d adur deffir",
"Alignment": "Tarigla",
"Border color": "Ini n yiri",
"Column group": "Agraw n tgejda",
"Row": "Adur",
"Insert column before": "Sente\u1e0d tagejdit sdat",
"Split cell": "B\u1e0du tixxamin",
"Cell padding": "Tama n texxamt",
"Cell spacing": "Tlunt ger texxamin",
"Row type": "Anaw n wadur",
"Insert table": "Ger tafelwit",
"Body": "Tafka",
"Caption": "Caption",
"Footer": "A\u1e0dar",
"Delete row": "Kkes tagejdit",
"Paste row before": "Sente\u1e0d adur sdat",
"Scope": "Scope",
"Delete table": "Kkes tafelwit",
"H Align": "Tarigla taglawant",
"Top": "Uksawen",
"Header cell": "Tasen\u1e6di\u1e0dt n texxamt",
"Column": "Tagejdit",
"Row group": "Agraw n waduren",
"Cell": "Taxxamt",
"Middle": "Di tlemmast",
"Cell type": "Anaw n texxamt",
"Copy row": "N\u0263el adur",
"Row properties": "Iraten n udur",
"Table properties": "Iraten n tfelwit",
"Bottom": "Uksar",
"V Align": "Tarigla taratakt",
"Header": "Tasenti\u1e0dt",
"Right": "\u0194er yefus",
"Insert column after": "Sente\u1e0d tagejdit deffir",
"Cols": "Tigejda",
"Insert row after": "Ger adur sdat",
"Width": "Tehri",
"Cell properties": "Iraten n texxamt",
"Left": "\u0194er zelma\u1e0d",
"Cut row": "Gzem adur",
"Delete column": "Kkes tagejdit",
"Center": "Di tlemmast",
"Merge cells": "Seddukel tixxamin",
"Insert template": "Ger tamuddimt",
"Templates": "Timudimin",
"Background color": "Ini n ugilal",
"Custom...": "Custom...",
"Custom color": "Custom color",
"No color": "Ulac ini",
"Text color": "Ini n u\u1e0dris",
"Show blocks": "Beqqe\u1e0d i\u1e25edran",
"Show invisible characters": "Beqqe\u1e0d isekkilen uffiren",
"Words: {0}": "Words: {0}",
"Insert": "Ger",
"File": "Afaylu",
"Edit": "\u1e92reg",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help",
"Tools": "Ifecka",
"View": "Tamu\u0263li",
"Table": "Tafelwit",
"Format": "Amasal"
});