tinymce.addI18n('lt',{
"Cut": "I\u0161kirpti",
"Heading 5": "Antra\u0161t\u0117 5",
"Header 2": "Antra\u0161t\u0117 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Nar\u0161ykl\u0117s nustatymai neleid\u017eia redaktoriui tiesiogiai pasiekti laikinosios atminties. Pra\u0161ome naudoti klaviat\u016bros klavi\u0161us Ctrl+X\/C\/V.",
"Heading 4": "Antra\u0161t\u0117 4",
"Div": "Div",
"Heading 2": "Antra\u0161t\u0117 2",
"Paste": "\u012ed\u0117ti",
"Close": "U\u017edaryti",
"Font Family": "\u0160riftas",
"Pre": "Pre",
"Align right": "Lygiuoti de\u0161in\u0117je",
"New document": "Naujas dokumentas",
"Blockquote": "Citata",
"Numbered list": "Skaitmeninis s\u0105ra\u0161as",
"Heading 1": "Antra\u0161t\u0117 1",
"Headings": "Antra\u0161t\u0117s",
"Increase indent": "Didinti \u012ftrauk\u0105",
"Formats": "Formatai",
"Headers": "Antra\u0161t\u0117s",
"Select all": "Pa\u017eym\u0117ti visk\u0105",
"Header 3": "Antra\u0161t\u0117 3",
"Blocks": "Blokai",
"Undo": "Atstatyti",
"Strikethrough": "Perbrauktas",
"Bullet list": "\u017denklinimo s\u0105ra\u0161as",
"Header 1": "Antra\u0161t\u0117 1",
"Superscript": "Vir\u0161utinis indeksas",
"Clear formatting": "Naikinti formatavim\u0105",
"Font Sizes": "\u0160rifto dyd\u017eiai",
"Subscript": "Apatinis indeksas",
"Header 6": "Antra\u0161t\u0117 6",
"Redo": "Gr\u0105\u017einti",
"Paragraph": "Paragrafas",
"Ok": "Gerai",
"Bold": "Pary\u0161kintas",
"Code": "Kodas",
"Italic": "Kursyvinis",
"Align center": "Centruoti",
"Header 5": "Antra\u0161t\u0117 5",
"Heading 6": "Antra\u0161t\u0117 6",
"Heading 3": "Antra\u0161t\u0117 3",
"Decrease indent": "Ma\u017einti \u012ftrauk\u0105",
"Header 4": "Antra\u0161t\u0117 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Dabar \u012fterpiama paprastojo teksto re\u017eimu. Kol \u0161i parinktis \u012fjungta, turinys bus \u012fterptas kaip paprastas tekstas.",
"Underline": "Pabrauktas",
"Cancel": "Atsisakyti",
"Justify": "I\u0161d\u0117styti per vis\u0105 plot\u012f",
"Inline": "Inline",
"Copy": "Kopijuoti",
"Align left": "Lygiuoti kair\u0117je",
"Visual aids": "Vaizdin\u0117s priemon\u0117s",
"Lower Greek": "Ma\u017eosios graik\u0173",
"Square": "Kvadratas",
"Default": "Pagrindinis",
"Lower Alpha": "Ma\u017eosios raid\u0117s",
"Circle": "Apskritimas",
"Disc": "Diskas",
"Upper Alpha": "Did\u017eiosios raid\u0117s",
"Upper Roman": "Did\u017eiosios rom\u0117n\u0173",
"Lower Roman": "Ma\u017eosios rom\u0117n\u0173",
"Name": "Pavadinimas",
"Anchor": "\u017dym\u0117",
"You have unsaved changes are you sure you want to navigate away?": "Turite nei\u0161saugot\u0173 pakeitim\u0173! Ar tikrai norite i\u0161eiti?",
"Restore last draft": "Atstatyti paskutin\u012f projekt\u0105",
"Special character": "Specialus simbolis",
"Source code": "Pirminis \u0161altinis",
"Color": "Spalva",
"Right to left": "I\u0161 de\u0161in\u0117s \u012f kair\u0119",
"Left to right": "I\u0161 kair\u0117s \u012f de\u0161in\u0119",
"Emoticons": "Jaustukai",
"Robots": "Robotai",
"Document properties": "Dokumento savyb\u0117s",
"Title": "Pavadinimas",
"Keywords": "\u017dymos",
"Encoding": "Kodavimas",
"Description": "Apra\u0161as",
"Author": "Autorius",
"Fullscreen": "Visas ekranas",
"Horizontal line": "Horizontali linija",
"Horizontal space": "Horizontalus tarpas",
"B": "B",
"Insert\/edit image": "\u012eterpti|Tvarkyti paveiksl\u0117l\u012f",
"General": "Bendra",
"Advanced": "I\u0161pl\u0117stas",
"G": "G",
"R": "R",
"Source": "Pirmin\u0117 nuoroda",
"Border": "R\u0117melis",
"Constrain proportions": "Laikytis proporcij\u0173",
"Vertical space": "Vertikalus tarpas",
"Image description": "Paveiksl\u0117lio apra\u0161as",
"Style": "Stilius",
"Dimensions": "Matmenys",
"Insert image": "\u012eterpti paveiksl\u0117l\u012f",
"Insert date\/time": "\u012eterpti dat\u0105\/laik\u0105",
"Remove link": "\u0160alinti nuorod\u0105",
"Url": "Nuoroda",
"Text to display": "Rodomas tekstas",
"Anchors": "\u017dym\u0117",
"Insert link": "\u012eterpti nuorod\u0105",
"New window": "Naujas langas",
"None": "Nieko",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Atrodo, kad \u012fved\u0117te nuotolin\u0119 nuorod\u0105. Ar norite prie\u0161 j\u0105 \u012fvesti reikalaujam\u0105 \u201ehttp:\/\/\u201c?",
"Target": "Tikslin\u0117 nuoroda",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Atrodo, kad \u012fvesta nuoroda yra elektroninio pa\u0161to adresas. Ar prad\u017eioje norite \u012fvesti reikalaujam\u0105 \u201emailto:\u201c?",
"Insert\/edit link": "\u012eterpti\/taisyti nuorod\u0105",
"Insert\/edit video": "\u012eterpti\/tvarkyti video",
"Poster": "Plakatas",
"Alternative source": "Alternatyvus \u0161altinis",
"Paste your embed code below:": "\u012eterpkite kod\u0105 \u017eemiau:",
"Insert video": "\u012eterpti video",
"Embed": "\u012eterpti",
"Nonbreaking space": "Nepertraukiamos vietos",
"Page break": "Puslapio skirtukas",
"Paste as text": "\u012eklijuoti kaip tekst\u0105",
"Preview": "Per\u017ei\u016bra",
"Print": "Spausdinti",
"Save": "I\u0161saugoti",
"Could not find the specified string.": "Nepavyko rasti nurodytos eilut\u0117s.",
"Replace": "Pakeisti",
"Next": "Sekantis",
"Whole words": "Visus \u017eod\u017eius",
"Find and replace": "Surasti ir pakeisti",
"Replace with": "Kuo pakeisti",
"Find": "Ie\u0161koti",
"Replace all": "Pakeisti visk\u0105",
"Match case": "Atitinkamus",
"Prev": "Ankstesnis",
"Spellcheck": "Ra\u0161ybos tikrinimas",
"Finish": "Baigti",
"Ignore all": "Ignoruoti visk\u0105",
"Ignore": "Ignoruoti",
"Add to Dictionary": "Prid\u0117ti \u012f \u017dodyn\u0105",
"Insert row before": "\u012eterpti eilut\u0119 prie\u0161",
"Rows": "Eilut\u0117s",
"Height": "Auk\u0161tis",
"Paste row after": "\u012ed\u0117ti eilut\u0119 po",
"Alignment": "Lygiavimas",
"Border color": "Sien\u0173 spalva",
"Column group": "Stulpeli\u0173 grup\u0117",
"Row": "Eilut\u0117s",
"Insert column before": "\u012eterpti stulpel\u012f prie\u0161",
"Split cell": "Skaidyti langelius",
"Cell padding": "Tarpas nuo langelio iki teksto",
"Cell spacing": "Tarpas tarp langeli\u0173",
"Row type": "Eilu\u010di\u0173 tipas",
"Insert table": "\u012eterpti lentel\u0119",
"Body": "Turinys",
"Caption": "Antra\u0161t\u0117",
"Footer": "Apa\u010dia",
"Delete row": "Naikinti eilut\u0119",
"Paste row before": "\u012ed\u0117ti eilut\u0119 prie\u0161",
"Scope": "Strukt\u016bra",
"Delete table": "\u0160alinti lentel\u0119",
"H Align": "H Lygiavimas",
"Top": "Vir\u0161uje",
"Header cell": "Antra\u0161t\u0117s langelis",
"Column": "Stulpelis",
"Row group": "Eilu\u010di\u0173 grup\u0117",
"Cell": "Langeliai",
"Middle": "Viduryje",
"Cell type": "Langelio tipas",
"Copy row": "Kopijuoti eilut\u0119",
"Row properties": "Eilut\u0117s savyb\u0117s",
"Table properties": "Lentel\u0117s savyb\u0117s",
"Bottom": "Apa\u010dioje",
"V Align": "V Lygiavimas",
"Header": "Antra\u0161t\u0117",
"Right": "De\u0161in\u0117",
"Insert column after": "\u012eterpti stulpel\u012f po",
"Cols": "Stulpeliai",
"Insert row after": "\u012eterpti eilut\u0119 po",
"Width": "Plotis",
"Cell properties": "Langelio savyb\u0117s",
"Left": "Kair\u0117",
"Cut row": "I\u0161kirpti eilut\u0119",
"Delete column": "Naikinti stulpel\u012f",
"Center": "Centras",
"Merge cells": "Sujungti langelius",
"Insert template": "\u012eterpti \u0161ablon\u0105",
"Templates": "\u0160ablonai",
"Background color": "Fono spalva",
"Custom...": "Pasirinktinas...",
"Custom color": "Pasirinktina spalva",
"No color": "Jokios spalvos",
"Text color": "Teksto spalva",
"Show blocks": "Rodyti blokus",
"Show invisible characters": "Rodyti nematomus simbolius",
"Words: {0}": "\u017dod\u017eiai: {0}",
"Insert": "\u012eterpti",
"File": "Failas",
"Edit": "Redaguoti",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Suformatuoto teksto laukas. D\u0117l meniu spauskite ALT-F9. U\u017eduo\u010di\u0173 juostos \u012fjungimui spauskite ALT-F10. Pagalbai - spauskite ALT-0.",
"Tools": "\u012erankiai",
"View": "Per\u017ei\u016bra",
"Table": "Lentel\u0117",
"Format": "Formatas"
});