tinymce.addI18n('fo',{
"Cut": "Klipp",
"Heading 5": "Yvirskrift 5",
"Header 2": "H\u00f8vd 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "T\u00edn kagi hevur ikki beinlei\u00f0is atgongd til setibor\u00f0i\u00f0. Vinarliga br\u00faka CTRL+X\/C\/V snarvegirnar \u00edsta\u00f0in.",
"Heading 4": "Yvirskrift 4",
"Div": "DIv",
"Heading 2": "Yvirskrift 2",
"Paste": "L\u00edma",
"Close": "Lat aftur",
"Font Family": "Stav familja",
"Pre": "Pre",
"Align right": "H\u00f8gra stilla",
"New document": "N\u00fdtt skjal",
"Blockquote": "Blokksitat",
"Numbered list": "Tal listi",
"Heading 1": "Yvirskrift 1",
"Headings": "Yvirskriftir",
"Increase indent": "Vaks inndr\u00e1tt",
"Formats": "Sni\u00f0",
"Headers": "H\u00f8vd",
"Select all": "Vel alt",
"Header 3": "H\u00f8vd 3",
"Blocks": "Blokkar",
"Undo": "Angra ger",
"Strikethrough": "Strika \u00edgj\u00f8gnum",
"Bullet list": "Punkt listi",
"Header 1": "H\u00f8vd 1",
"Superscript": "H\u00e1skrift",
"Clear formatting": "Strika sni\u00f0",
"Font Sizes": "Stav st\u00f8dd",
"Subscript": "L\u00e1gskrift",
"Header 6": "H\u00f8vd 6",
"Redo": "Ger aftur",
"Paragraph": "T\u00e1ttur",
"Ok": "Ok",
"Bold": "Feit",
"Code": "Kota",
"Italic": "Sk\u00e1ktekstur",
"Align center": "Mi\u00f0set",
"Header 5": "H\u00f8vd 5",
"Heading 6": "Yvirskrift 6",
"Heading 3": "Yvirskrift 3",
"Decrease indent": "Minka inndr\u00e1tt",
"Header 4": "H\u00f8vd 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Klistra er n\u00fa \u00ed vanligum tekst standi. Innihald ver\u00f0ur n\u00fa klistra sum vanligur tekstur, inntil t\u00fa sl\u00f8kkir hendan standin.",
"Underline": "Undirstrika",
"Cancel": "\u00d3gilda",
"Justify": "L\u00edka breddar",
"Inline": "\u00cd linju",
"Copy": "Avrita",
"Align left": "Vinstra stilla",
"Visual aids": "Sj\u00f3nhj\u00e1lp",
"Lower Greek": "L\u00edti Grikskt",
"Square": "Fj\u00f3rhyrningur",
"Default": "Forsettur",
"Lower Alpha": "L\u00edti Alfa",
"Circle": "Ringur",
"Disc": "Skiva",
"Upper Alpha": "St\u00f3rt Alfa",
"Upper Roman": "St\u00f3rt R\u00f3mverskt",
"Lower Roman": "L\u00edti R\u00f3mverskt",
"Name": "Navn",
"Anchor": "Akker",
"You have unsaved changes are you sure you want to navigate away?": "T\u00fa hevur ikki goymdar broytingar. Ert t\u00fa v\u00edsur \u00ed at t\u00fa vilt halda fram?",
"Restore last draft": "Endurskapa seinasta uppkast",
"Special character": "Serst\u00f8k tekn",
"Source code": "keldukoda",
"B": "B",
"R": "R",
"G": "G",
"Color": "Litur",
"Right to left": "H\u00f8gra til vinstra",
"Left to right": "Vinstra til h\u00f8gra",
"Emoticons": "Emotikonur",
"Robots": "Robottar",
"Document properties": "Skjal eginleikar",
"Title": "Heiti",
"Keywords": "Leitior\u00f0",
"Encoding": "Koding",
"Description": "L\u00fdsing",
"Author": "H\u00f8vundur",
"Fullscreen": "Fullan sk\u00edggja",
"Horizontal line": "Vatnr\u00f8tt linja",
"Horizontal space": "Vatnr\u00e6tt fr\u00e1st\u00f8\u00f0a",
"Insert\/edit image": "Innset\/r\u00e6tta mynd",
"General": "Vanligt",
"Advanced": "Framkomi",
"Source": "Kelda",
"Border": "Rammi",
"Constrain proportions": "Var\u00f0veit lutfall",
"Vertical space": "Loddr\u00e6t fr\u00e1st\u00f8\u00f0a",
"Image description": "L\u00fdsing av mynd",
"Style": "St\u00edlur",
"Dimensions": "St\u00f8dd",
"Insert image": "Innset mynd",
"Zoom in": "Drag n\u00e6rri",
"Contrast": "M\u00f3tsetningur",
"Back": "Aftur",
"Gamma": "Gamma",
"Flip horizontally": "Vippa vatnr\u00e6tt",
"Resize": "Broyt st\u00f8dd",
"Sharpen": "Skerpa",
"Zoom out": "Tr\u00fdst burtur",
"Image options": "Mynda valm\u00f8guleikar",
"Apply": "Set \u00e1",
"Brightness": "Lj\u00f3s",
"Rotate clockwise": "Mal runt vi\u00f0 klokkuni",
"Rotate counterclockwise": "Mal runt \u00edm\u00f3ti klokkuni",
"Edit image": "R\u00e6tta mynd",
"Color levels": "Lit stig",
"Crop": "Klipp av",
"Orientation": "Helling",
"Flip vertically": "Vippa loddr\u00e6tt",
"Invert": "Vend \u00f8vut",
"Insert date\/time": "Innset dag\/t\u00ed\u00f0",
"Remove link": "Strika leinki",
"Url": "Url",
"Text to display": "Tekstur at v\u00edsa",
"Anchors": "Akker",
"Insert link": "Innset leinkju",
"New window": "N\u00fdggjan glugga",
"None": "Eingin",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Tann URL t\u00fa skriva\u00f0i s\u00e6r \u00fat til at ver\u00f0a ein uttanh\u00fdsis adressa. Ynskir t\u00fa at seta ta\u00f0 kravda http:\/\/ forskoyti frammanfyri?",
"Target": "M\u00e1l",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Tann URL t\u00fa skriva\u00f0i s\u00e6r \u00fat til at vera ein teldupost adressa. Ynskir t\u00fa at seta ta\u00f0 kravda mailto: forskoyti frammanfyri?",
"Insert\/edit link": "Innset\/r\u00e6tta leinkju",
"Insert\/edit video": "Innset\/r\u00e6tta kykmynd",
"Poster": "Uppslag",
"Alternative source": "Onnur kelda",
"Paste your embed code below:": "Innset ta\u00f0 kodu, sum skal leggjast inn \u00ed, ni\u00f0anfyri:",
"Insert video": "Innset kykmynd",
"Embed": "Legg inn \u00ed",
"Nonbreaking space": "Hart millumr\u00fam",
"Page break": "S\u00ed\u00f0uskift",
"Paste as text": "Klistra sum tekst",
"Preview": "V\u00eds frammanundan",
"Print": "Prenta",
"Save": "Goym",
"Could not find the specified string.": "Kundi ikki finna leititekst",
"Replace": "Skift \u00fat",
"Next": "N\u00e6sta",
"Whole words": "Heil or\u00f0",
"Find and replace": "Finn og skift \u00fat",
"Replace with": "Set \u00edsta\u00f0in",
"Find": "Finn",
"Replace all": "Skift alt \u00fat",
"Match case": "Samsvara st\u00f3rar og l\u00edtlar b\u00f3kstavir",
"Prev": "Fyrra",
"Spellcheck": "R\u00e6ttstavari",
"Finish": "Enda",
"Ignore all": "Leyp alt um",
"Ignore": "Leyp um",
"Add to Dictionary": "Legg til or\u00f0ab\u00f3k",
"Insert row before": "Innset ra\u00f0 \u00e1\u00f0renn",
"Rows": "R\u00f8\u00f0",
"Height": "H\u00e6dd",
"Paste row after": "L\u00edma ra\u00f0 aftan\u00e1",
"Alignment": "Stilling",
"Border color": "Kant litur",
"Column group": "Teig b\u00f3lkur",
"Row": "Ra\u00f0",
"Insert column before": "Innset teig \u00e1\u00f0renn",
"Split cell": "Syndra puntar",
"Cell padding": "Punt fylling",
"Cell spacing": "Punt fr\u00e1st\u00f8\u00f0a",
"Row type": "Ra\u00f0 slag",
"Insert table": "Innset talvu",
"Body": "Likam",
"Caption": "Tekstur",
"Footer": "F\u00f3tur",
"Delete row": "Skrika ra\u00f0",
"Paste row before": "L\u00edma ra\u00f0 \u00e1\u00f0renn",
"Scope": "N\u00fdtslu\u00f8ki",
"Delete table": "Strika talvu",
"H Align": "Vatnr\u00e6tt stilla",
"Top": "Ovast",
"Header cell": "H\u00f8vd puntur",
"Column": "Teigur",
"Row group": "Ra\u00f0 b\u00f3lkur",
"Cell": "Puntur",
"Middle": "\u00cd mi\u00f0juni",
"Cell type": "Punt slag",
"Copy row": "Avrita ra\u00f0",
"Row properties": "Ra\u00f0 eginleikar",
"Table properties": "Talvu eginleikar",
"Bottom": "Ni\u00f0ast",
"V Align": "Loddr\u00e6tt stilla",
"Header": "H\u00f8vd",
"Right": "H\u00f8gra",
"Insert column after": "Innset teig aftan\u00e1",
"Cols": "Teigar",
"Insert row after": "Innset ra\u00f0 aftan\u00e1",
"Width": "Breidd",
"Cell properties": "Punt eginleikar",
"Left": "Vinstra",
"Cut row": "Klipp ra\u00f0",
"Delete column": "Strika teig",
"Center": "Mi\u00f0a",
"Merge cells": "Fl\u00e6tta puntar",
"Insert template": "Innset form",
"Templates": "Formur",
"Background color": "Bakgrundslitur",
"Custom...": "Laga til...",
"Custom color": "Tillaga lit",
"No color": "Eingin litur",
"Text color": "Tekst litur",
"Show blocks": "V\u00eds blokkar",
"Show invisible characters": "V\u00eds \u00f3sj\u00f3nlig tekn",
"Words: {0}": "Or\u00f0: {0}",
"Insert": "Innset",
"File": "F\u00edla",
"Edit": "Ritstj\u00f3rna",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "R\u00edkt Tekst \u00d8ki. Tr\u00fdst ALT-F9 fyri valmynd. Tr\u00fdst ALT-F10 fyri ambo\u00f0slinju. Tr\u00fdst ALT-0 fyri hj\u00e1lp",
"Tools": "Ambo\u00f0",
"View": "V\u00eds",
"Table": "Talva",
"Format": "Sni\u00f0"
});