tinymce.addI18n('cy',{
"Cut": "Torri",
"Header 2": "Pennawd 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Dyw eich porwr ddim yn cynnal mynediad uniongyrchol i'r clipfwrdd. Defnyddiwch yr allweddau llwybr brys Ctrl+X\/C\/V yn lle 'ny.",
"Div": "Div",
"Paste": "Gludo",
"Close": "Cau",
"Font Family": "Teulu Ffont",
"Pre": "Pre",
"Align right": "Aliniad dde",
"New document": "Dogfen newydd",
"Blockquote": "Dyfyniad bloc",
"Numbered list": "Rhestr rifol",
"Increase indent": "Cynyddu mewnoliad",
"Formats": "Fformatiau",
"Headers": "Penawdau",
"Select all": "Dewis popeth",
"Header 3": "Pennawd 3",
"Blocks": "Blociau",
"Undo": "Dadwneud",
"Strikethrough": "Llinell drwodd",
"Bullet list": "Rhestr fwled",
"Header 1": "Pennawd 1",
"Superscript": "Uwchsgript",
"Clear formatting": "Clirio fformatio",
"Font Sizes": "Meintiau Ffont",
"Subscript": "Is-sgript",
"Header 6": "Pennawd 6",
"Redo": "AIlwneud",
"Paragraph": "Paragraff",
"Ok": "Iawn",
"Bold": "Bras",
"Code": "Cod",
"Italic": "Italig",
"Align center": "Aliniad canol",
"Header 5": "Pennawd 5",
"Decrease indent": "Lleinhau mewnoliad",
"Header 4": "Pennawd 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Mae gludo o fewn modd testun plaen. Caiff y cynnwys ei ludo ar ffurf destun plaen tan gaiff yr opsiwn ei doglo bant.",
"Underline": "Tanlinellu",
"Cancel": "Canslo",
"Justify": "Unioni",
"Inline": "Mewn llinell",
"Copy": "Cop\u00efo",
"Align left": "Aliniad chwith",
"Visual aids": "Cymorth gweledol",
"Lower Greek": "Groeg Is",
"Square": "Sgw\u00e2r",
"Default": "Diofyn",
"Lower Alpha": "Alffa Is",
"Circle": "Cylch",
"Disc": "Disg",
"Upper Alpha": "Alffa Uwch",
"Upper Roman": "Rhufeinig Uwch",
"Lower Roman": "Rhufeinig Is",
"Name": "Enw",
"Anchor": "Angor",
"You have unsaved changes are you sure you want to navigate away?": "Mae newidiadau heb eu cadw - ydych chi wir am symud i ffwrdd?",
"Restore last draft": "Adfer y drafft olaf",
"Special character": "Nod arbennig",
"Source code": "Cod gwreiddiol",
"Right to left": "Dde i'r chwith",
"Left to right": "Chwith i'r dde",
"Emoticons": "Gwenogluniau",
"Robots": "Robotiaid",
"Document properties": "Priodweddau'r ddogfen",
"Title": "Teitl",
"Keywords": "Allweddeiriau",
"Encoding": "Amgodiad",
"Description": "Disgrifiad",
"Author": "Awdur",
"Fullscreen": "Sgrin llawn",
"Horizontal line": "Llinell lorweddol",
"Horizontal space": "Gofod llorweddol",
"Insert\/edit image": "Mewnosod\/golygu delwedd",
"General": "Cyffredinol",
"Advanced": "Uwch",
"Source": "Ffynhonnell",
"Border": "Ymyl",
"Constrain proportions": "Gorfodi cyfrannedd",
"Vertical space": "Gofod fertigol",
"Image description": "Disgrifiad y ddelwedd",
"Style": "Arddull",
"Dimensions": "Dimensiynau",
"Insert image": "Mewnosod delwedd",
"Insert date\/time": "Mewnosod dyddiad\/amser",
"Remove link": "Tynnu dolen",
"Url": "Url",
"Text to display": "Testun i'w ddangos",
"Anchors": "Angorau",
"Insert link": "Mewnosod dolen",
"New window": "Ffenest newydd",
"None": "Dim",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Mae'n debyg taw dolen allanol yw'r URL hwn. Ydych chi am ychwanegu'r rhagosodiad http:\/\/ ?",
"Target": "Targed",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Mae'n debyg taw cyfeiriad ebost yw'r URL hwn. Ydych chi am ychwanegu'r rhagosodiad mailto:?",
"Insert\/edit link": "Mewnosod\/golygu dolen",
"Insert\/edit video": "Mewnosod\/golygu fideo",
"Poster": "Poster",
"Alternative source": "Ffynhonnell amgen",
"Paste your embed code below:": "Gludwch eich cod mewnosod isod:",
"Insert video": "Mewnosod fideo",
"Embed": "Mewnosod",
"Nonbreaking space": "Bwlch heb dorri",
"Page break": "Toriad tudalen",
"Paste as text": "Gludo fel testun",
"Preview": "Rhagolwg",
"Print": "Argraffu",
"Save": "Cadw",
"Could not find the specified string.": "Methu ffeindio'r llinyn hwnnw.",
"Replace": "Amnewid",
"Next": "Nesaf",
"Whole words": "Geiriau cyfan",
"Find and replace": "Chwilio ac amnewid",
"Replace with": "Amnewid gyda",
"Find": "Chwilio",
"Replace all": "Amnewid pob",
"Match case": "Cydweddu'r un c\u00eas",
"Prev": "Cynt",
"Spellcheck": "Sillafydd",
"Finish": "Gorffen",
"Ignore all": "Amwybyddu pob",
"Ignore": "Anwybyddu",
"Insert row before": "Mewnosod rhes cyn",
"Rows": "Rhesi",
"Height": "Uchder",
"Paste row after": "Gludo rhes ar \u00f4l",
"Alignment": "Aliniad",
"Column group": "Gr\u0175p colofn",
"Row": "Rhes",
"Insert column before": "Mewnosod colofn cyn",
"Split cell": "Hollti celloedd",
"Cell padding": "Padio cell",
"Cell spacing": "Bylchiau cell",
"Row type": "Math y rhes",
"Insert table": "Mewnosod tabl",
"Body": "Corff",
"Caption": "Pennawd",
"Footer": "Troedyn",
"Delete row": "Dileu rhes",
"Paste row before": "Gludo rhes cyn",
"Scope": "Sgop",
"Delete table": "Dileu'r tabl",
"Header cell": "Cell bennawd",
"Column": "Colofn",
"Cell": "Cell",
"Header": "Pennyn",
"Cell type": "Math y gell",
"Copy row": "Cop\u00efo rhes",
"Row properties": "Priodweddau rhes",
"Table properties": "Priodweddau tabl",
"Row group": "Gr\u0175p rhes",
"Right": "Dde",
"Insert column after": "Mewnosod colofn ar \u00f4l",
"Cols": "Col'u",
"Insert row after": "Mewnosod rhes ar \u00f4l",
"Width": "Lled",
"Cell properties": "Priodweddau'r gell",
"Left": "Chwith",
"Cut row": "Torri rhes",
"Delete column": "Dileu colofn",
"Center": "Canol",
"Merge cells": "Cyfuno celloedd",
"Insert template": "Mewnosod templed",
"Templates": "Templedi",
"Background color": "Lliw cefndir",
"Text color": "Lliw testun",
"Show blocks": "Dangos blociau",
"Show invisible characters": "Dangos nodau anweledig",
"Words: {0}": "Geiriau: {0}",
"Insert": "Mewnosod",
"File": "Ffeil",
"Edit": "Golygu",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Ardal Testun Uwch. Pwyswch ALT-F9 ar gyfer y ddewislen, Pwyswch ALT-F10 ar gyfer y bar offer. Pwyswch ALT-0 am gymorth",
"Tools": "Offer",
"View": "Dangos",
"Table": "Tabl",
"Format": "Fformat"
});