<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <title>TinyMCE 4 Editor Example</title>
  {{ form.media }}
</head>
<body>
<h1>TinyMCE 4 Editor Example</h1>
<hr>
<form action="" method="post">
  {% csrf_token %}
  {{ form.as_p }}
  <input type="submit" value="Create" disabled />
</form>
</body>
</html>
