tinymce.addI18n('gd',{
"Cut": "Gearr \u00e0s",
"Heading 5": "Ceann-sgr\u00ecobhadh 5",
"Header 2": "Bann-cinn 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "Chan eil am brabhsair agad a' cur taic ri inntrigeadh d\u00ecreach dhan st\u00f2r-bh\u00f2rd. Cleachd ath-ghoiridean a' mheur-chl\u00e0ir, Ctrl+X\/V\/V 'nan \u00e0ite.",
"Heading 4": "Ceann-sgr\u00ecobhadh 4",
"Div": "Div",
"Heading 2": "Ceann-sgr\u00ecobhadh 2",
"Paste": "Cuir ann",
"Close": "D\u00f9in",
"Font Family": "Teaghlach a' chrutha-chl\u00f2",
"Pre": "Pre",
"Align right": "Co-thaobhaich ris an l\u00e0imh dheas",
"New document": "Sgr\u00ecobhainn \u00f9r",
"Blockquote": "Bloc-luaidh",
"Numbered list": "Liosta \u00e0ireamhaichte",
"Heading 1": "Ceann-sgr\u00ecobhadh 1",
"Headings": "Ceann-sgr\u00ecobhaidhean",
"Increase indent": "Meudaich an eag",
"Formats": "F\u00f2rmatan",
"Headers": "Bannan-cinn",
"Select all": "Tagh na h-uile",
"Header 3": "Bann-cinn 3",
"Blocks": "Blocaichean",
"Undo": "Neo-dh\u00e8an",
"Strikethrough": "Loidhne troimhe",
"Bullet list": "Liosta pheilearaichte",
"Header 1": "Bann-cinn 1",
"Superscript": "Os-sgr\u00ecobhte",
"Clear formatting": "Falamhaich am f\u00f2rmatadh",
"Font Sizes": "Meudan nan cruthan-chl\u00f2",
"Subscript": "Bun-sgr\u00ecobhte",
"Header 6": "Bann-cinn 6",
"Redo": "Ath-dh\u00e8an",
"Paragraph": "Paragraf",
"Ok": "Ceart ma-th\u00e0",
"Bold": "Trom",
"Code": "C\u00f2d",
"Italic": "Eadailteach",
"Align center": "Co-thaobhaich ris a' mheadhan",
"Header 5": "Bann-cinn 5",
"Heading 6": "Ceann-sgr\u00ecobhadh 6",
"Heading 3": "Ceann-sgr\u00ecobhadh 3",
"Decrease indent": "Lughdaich an eag",
"Header 4": "Bann-cinn 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Ma chuireas tu rud ann a-nis, th\u00e8id an t-susbaint a chur ann mar theacsa lom gus an cuir thu dheth an roghainn seo a-rithist.",
"Underline": "Fo-loidhne",
"Cancel": "Sguir dheth",
"Justify": "Blocaich",
"Inline": "Taobh a-staigh na loidhne",
"Copy": "D\u00e8an lethbhreac",
"Align left": "Co-thaobhaich ris an l\u00e0imh chl\u00ec",
"Visual aids": "Taic l\u00e8irsinne",
"Lower Greek": "Litrichean Greugach beaga",
"Square": "Ce\u00e0rnag",
"Default": "Bun-roghainn",
"Lower Alpha": "Aibidileach is beag",
"Circle": "Cearcall",
"Disc": "Diosga",
"Upper Alpha": "Aibidileach is m\u00f2r",
"Upper Roman": "\u00c0ireamhan R\u00f2manach is m\u00f2r",
"Lower Roman": "\u00c0ireamhan R\u00f2manach is beag",
"Name": "Ainm",
"Anchor": "Acair",
"You have unsaved changes are you sure you want to navigate away?": "Tha atharraichean gun s\u00e0bhaladh agad, a bheil thu cinnteach gu bheil thu airson gluasad air falbh?",
"Restore last draft": "Aisig an dreach mu dheireadh",
"Special character": "Caractar s\u00f2nraichte",
"Source code": "An c\u00f2d t\u00f9sail",
"Color": "Dath",
"Right to left": "Deas gu cl\u00ec",
"Left to right": "Cl\u00ec gu deas",
"Emoticons": "Samhlaidhean-gn\u00f9ise",
"Robots": "Robotairean",
"Document properties": "Roghainnean na sgr\u00ecobhainne",
"Title": "Tiotal",
"Keywords": "Faclan-luirg",
"Encoding": "C\u00f2dachadh",
"Description": "Tuairisgeul",
"Author": "\u00d9ghdar",
"Fullscreen": "L\u00e0n-sgr\u00ecn",
"Horizontal line": "Loidhne ch\u00f2mhnard",
"Horizontal space": "\u00c0ite c\u00f2mhnard",
"Insert\/edit image": "Cuir a-steach\/Deasaich an dealbh",
"General": "Coitcheann",
"Advanced": "Adhartach",
"Source": "T\u00f9s",
"Border": "Iomall",
"Constrain proportions": "Cuingich na co-r\u00e8irean",
"Vertical space": "\u00c0ite inghearach",
"Image description": "Tuairisgeul an deilbh",
"Style": "Stoidhle",
"Dimensions": "Meudachd",
"Insert image": "Cuir a-steach dealbh",
"Insert date\/time": "Cuir a-steach ceann-l\u00e0\/\u00e0m",
"Remove link": "Thoir air falbh an ceangal",
"Url": "URL",
"Text to display": "An teacsa a th\u00e8id a shealltainn",
"Anchors": "Acraichean",
"Insert link": "Cuir a-steach ceangal",
"New window": "Uinneag \u00f9r",
"None": "Chan eil gin",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "Tha coltas gu bheil an URL a chuir thu a-steach 'na cheangal ris an taobh a-muigh. A bheil thu airson an ro-leasachan http:\/\/ a chur ris? Tha feum air.",
"Target": "Targaid",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "Tha coltas gu bheil an URL a chuir thu a-steach 'na she\u00f2ladh puist-d. A bheil thu airson an ro-leasachan mailto: a chur ris? Tha feum air.",
"Insert\/edit link": "Cuir a-steach\/Deasaich an ceangal",
"Insert\/edit video": "Cuir a-steach\/Deasaich a' video",
"Poster": "P\u00f2stair",
"Alternative source": "Roghainn eile de th\u00f9s",
"Paste your embed code below:": "Cuir an c\u00f2d leabachaidh agad a-steach gu h-\u00ecosal:",
"Insert video": "Cuir a-steach video",
"Embed": "Leabaich",
"Nonbreaking space": "Be\u00e0rn neo-bhristidh",
"Page break": "Briseadh-duilleige",
"Paste as text": "Cuir ann mar theacsa",
"Preview": "Ro-shealladh",
"Print": "Cl\u00f2-bhuail",
"Save": "S\u00e0bhail",
"Could not find the specified string.": "Cha b' urrainn dhuinn na dh'iarr thu a lorg.",
"Replace": "Cuir 'na \u00e0ite",
"Next": "Air adhart",
"Whole words": "Faclan sl\u00e0na",
"Find and replace": "Lorg is cuir 'na \u00e0ite",
"Replace with": "Cuir na leanas 'na \u00e0ite",
"Find": "Lorg",
"Replace all": "Cuir an \u00e0ite na h-uile",
"Match case": "Maids litrichean m\u00f2ra 's beaga",
"Prev": "Air ais",
"Spellcheck": "Dearbhaich an litreachadh",
"Finish": "Cr\u00ecochnaich",
"Ignore all": "Leig seachad na h-uile",
"Ignore": "Leig seachad",
"Add to Dictionary": "Cuir ris an fhaclair",
"Insert row before": "Cuir a-steach r\u00e0gh roimhe",
"Rows": "R\u00e0ghan",
"Height": "\u00c0irde",
"Paste row after": "Cuir ann r\u00e0gh 'na dh\u00e8idh",
"Alignment": "Co-thaobhadh",
"Border color": "Dath an iomaill",
"Column group": "Buidheann cholbhan",
"Row": "R\u00e0gh",
"Insert column before": "Cuir a-steach colbh roimhe",
"Split cell": "Sgoilt an cealla",
"Cell padding": "Padadh nan ceallan",
"Cell spacing": "Be\u00e0rnadh nan ceallan",
"Row type": "Se\u00f2rsa an r\u00e0igh",
"Insert table": "Cuir a-steach cl\u00e0r",
"Body": "Bodhaig",
"Caption": "Caipsean",
"Footer": "Bann-coise",
"Delete row": "Sguab \u00e0s an r\u00e0gh",
"Paste row before": "Cuir ann r\u00e0gh roimhe",
"Scope": "Sg\u00f2p",
"Delete table": "Sguab \u00e0s an cl\u00e0r",
"H Align": "Co-thaobhadh c\u00f2mhnard",
"Top": "Barr",
"Header cell": "Cealla a' bhanna-chinn",
"Column": "Colbh",
"Row group": "Buidheann r\u00e0ghan",
"Cell": "Cealla",
"Middle": "Meadhan",
"Cell type": "Se\u00f2rsa a' chealla",
"Copy row": "D\u00e8an lethbhreac dhen r\u00e0gh",
"Row properties": "Roghainnean an r\u00e0igh",
"Table properties": "Roghainnean a' chl\u00e0ir",
"Bottom": "Bonn",
"V Align": "Co-thaobhadh inghearach",
"Header": "Bann-cinn",
"Right": "Deas",
"Insert column after": "Cuir a-steach colbh 'na dh\u00e8idh",
"Cols": "Colbhan",
"Insert row after": "Cuir a-steach r\u00e0gh 'na dh\u00e8idh",
"Width": "Leud",
"Cell properties": "Roghainnean a' chealla",
"Left": "Cl\u00ec",
"Cut row": "Gearr \u00e0s an r\u00e0gh",
"Delete column": "Sguab \u00e0s an colbh",
"Center": "Meadhan",
"Merge cells": "Co-aonaich na ceallan",
"Insert template": "Cuir a-steach teamplaid",
"Templates": "Teamplaidean",
"Background color": "Dath a\u2019 ch\u00f9laibh",
"Custom...": "Gn\u00e0thaichte...",
"Custom color": "Dath gn\u00e0thaichte",
"No color": "Gun dath",
"Text color": "Dath an teacsa",
"Show blocks": "Seall na blocaichean",
"Show invisible characters": "Seall na caractaran do-fhaicsinneach",
"Words: {0}": "Faclan: {0}",
"Insert": "Cuir a-steach",
"File": "Faidhle",
"Edit": "Deasaich",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "Raon Rich Text. Br\u00f9th ALT-F9 airson a' chl\u00e0ir-thaice. Br\u00f9th ALT-F10 airson a' bh\u00e0r-inneal. Br\u00f9th ALT-0 airson na cobharach.",
"Tools": "Innealan",
"View": "Sealladh",
"Table": "Cl\u00e0r",
"Format": "F\u00f2rmat"
});